@@ -10,6 +10,8 @@ import matplotlib.pyplot as plt
 from .plottools import *
 from .temp_newvisufunc import projview as temp_projview
 
+
+
 # Fix for macos openMP duplicate bug
 os.environ["KMP_DUPLICATE_LIB_OK"] = "True"
 
@@ -67,6 +69,8 @@ def plot(
     custom_ytick_labels=None,
     ratio=None,
     extend=None,
+    return_figure=False,
+    scale=1,
     **kwargs,
 ):
     """
@@ -208,10 +212,13 @@ def plot(
         override x-axis tick labels
     custom_ytick_labels : list
         override y-axis tick labels
+    scale : float
+        rescales data by factor scale
     kwargs : keywords
         passed to projview
     """
 
+
     if not fontsize:
         fontsize = DEFAULT_FONTSIZES
     else:
@@ -232,7 +239,9 @@ def plot(
         sig = STOKES.index(sig)
 
     # Get data
-    m, comp, freq, nside = get_data(input, sig, comp, freq, fwhm, nside=nside, sample=sample)
+    m, comp, freq, nside = get_data(input, sig, comp, freq, fwhm, nside=nside,
+        sample=sample, scale=scale, remove_dip=remove_dip,
+        remove_mono=remove_mono)
 
     # Mask map
     if mask is not None:
@@ -291,8 +300,6 @@ def plot(
         show_tickmarkers=True,
         width=width,
         # unedited params
-        remove_dip=remove_dip,
-        remove_mono=remove_mono,
         xsize=xsize,
         title=title,
         rot=rot,
@@ -319,4 +326,5 @@ def plot(
         **kwargs
     )
 
-    return ret, params
+    if return_figure:
+       return ret, params
