@@ -572,6 +572,7 @@ def projview(
                 rasterized=True,
                 cmap=cm,
                 shading="auto",
+                #shading="flat",
                 **kwargs,
             )
         elif projection_type == "3d":  # test for 3d plot
@@ -717,8 +718,9 @@ def projview(
             ticks = ticks[ticks<=max]
             labels = [format % tick if tick in cbar_ticks else "" for tick in ticks]
 
-            cb.set_ticks(ticks, labels)
+            cb.set_ticks(ticks)
             cb.set_ticklabels(labels)
+            print('am I even here though')
         else:
             labels = [format % tick for tick in cbar_ticks]
 
