@@ -1,15 +1,14 @@
-from astropy.units import Quantity
 import numpy as np
+from astropy.units import Quantity
 
 from cosmoglobe.data import DATA_DIR
 from cosmoglobe.sky._base_components import PointSourceComponent
-from cosmoglobe.sky.components import SkyComponentLabel
-
+from cosmoglobe.sky.components._labels import SkyComponentLabel
 
 RADIO_CATALOG = DATA_DIR / "radio_catalog.dat"
 
 
-class Radio(PointSourceComponent):
+class AGNPowerLaw(PointSourceComponent):
     r"""Class representing the radio component.
 
     Notes
